@@ -23,7 +23,7 @@ use File::HomeDir;
 use File::Spec::Functions;
 
 # Main version number that the rest of the modules pick up off of.
-our $VERSION = qv("4.13.0");
+our $VERSION = qv("4.14.0");
 
 use constant DEFAULT_PROPERTIES_FILE =>
   catfile(File::HomeDir->my_home, "adwords.properties");
@@ -35,7 +35,7 @@ use constant PROXY_FORMAT_STRING => "%s/api/adwords/%s/%s/%s";
 
 # Default current version used if the client is created without the version
 # parameter.
-use constant DEFAULT_VERSION => "v201702";
+use constant DEFAULT_VERSION => "v201705";
 
 # Default alternate URL that points to production servers.
 use constant DEFAULT_ALTERNATE_URL => "https://adwords.google.com";
@@ -69,9 +69,12 @@ our %SERVICE_TO_GROUP = (
   BudgetOrderService              => "billing",
   BudgetService                   => "cm",
   CampaignAdExtensionService      => "cm",
+  CampaignBidModifierService      => "cm",
   CampaignCriterionService        => "cm",
   CampaignExtensionSettingService => "cm",
   CampaignFeedService             => "cm",
+  CampaignGroupService            => "cm",
+  CampaignGroupPerformanceTargetService => "cm",
   CampaignService                 => "cm",
   CampaignSharedSetService        => "cm",
   ConstantDataService             => "cm",
